@@ -12,7 +12,7 @@ import urllib2
 import cgi
 import re
 
-__version__  = '0.10.1'
+__version__  = '0.10.2'
 __author__ = "Hiroki Ohtani (liris.pp@gmail.com)"
 __contributors__ = ["Junji NAKANISHI <daemonfreaks@gmail.com>"]
 __copyright__ = "Copyright (c) 2006 Hiroki Ohtani"
@@ -241,20 +241,20 @@ class Condition(object):
         Set options of retrieval.
         `options' specifies options: 
         
-        `Condition::SURE' specifies that it checks every N-gram key, 
+        `Condition.SURE' specifies that it checks every N-gram key, 
         
-        `Condition::USU', which is the default, 
+        `Condition.USUAL', which is the default, 
         specifies that it checks N-gram keys with skipping one key, 
         
-        `Condition::FAST' skips two keys, 
+        `Condition.FAST' skips two keys, 
 
-        `Condition::AGITO' skips three keys, 
+        `Condition.AGITO' skips three keys, 
         
-        `Condition::NOIDF' specifies not to perform TF-IDF tuning,
+        `Condition.NOIDF' specifies not to perform TF-IDF tuning,
         
-        `Condition::SIMPLE' specifies to use simplified phrase,
+        `Condition.SIMPLE' specifies to use simplified phrase,
         
-        `Condition::ROUGH' specifies to use rough phrase,
+        `Condition.ROUGH' specifies to use rough phrase,
 
         `Condition.UNION' specifies to use union phrase,
         
@@ -1019,7 +1019,7 @@ def _condToQuery(cond, depth, wwidth, hwidth, awidth):
     else:
         buf.append(("max", str(1<<30)))
     if cond.options > 0:
-        buf.appends(("options", str(cond.options)))
+        buf.append(("options", str(cond.options)))
     buf.append(("auxiliary", str(cond.auxiliary)))
     if cond.distinct:
         buf.append(("distinct", _escape(cond.distinct)))
